You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by lo...@apache.org on 2013/06/11 11:10:32 UTC

svn commit: r1491710 - in /myfaces/tobago/trunk: tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/html/ tobago-core/src/test/java/org/apache/myfaces/tobago/renderkit/html/ tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfa...

Author: lofwyr
Date: Tue Jun 11 09:10:31 2013
New Revision: 1491710

URL: http://svn.apache.org/r1491710
Log:
TOBAGO-1275: Change code style for html5 data attributes: separate words.

Modified:
    myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/html/DataAttributes.java
    myfaces/tobago/trunk/tobago-core/src/test/java/org/apache/myfaces/tobago/renderkit/html/DataAttributesUnitTest.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/CalendarRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/DatePickerRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuCommandRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/SheetRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TimeRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIconRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIndentRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeListboxRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeMenuNodeRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/HtmlRendererUtils.java
    myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-calendar.js
    myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-sheet.js
    myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-tree.js
    myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago.js

Modified: myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/html/DataAttributes.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/html/DataAttributes.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/html/DataAttributes.java (original)
+++ myfaces/tobago/trunk/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/html/DataAttributes.java Tue Jun 11 09:10:31 2013
@@ -30,7 +30,11 @@ public final class DataAttributes {
    * The index of the column of a sheet. This index means the position of the rendered column. It can differ, if there
    * are tc:column with rendered=false.
    */
-  public static final String COLUMNINDEX = "data-tobago-columnindex";
+  public static final String COLUMN_INDEX = "data-tobago-column-index";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String COLUMNINDEX = COLUMN_INDEX;
 
   /**
    * TBD: needed? may replace with VALUE?
@@ -47,12 +51,20 @@ public final class DataAttributes {
   /**
    * Reference to the corresponding date input field. Used for date picker popups.
    */
-  public static final String DATEINPUTID = "data-tobago-dateinputid";
+  public static final String DATE_INPUT_ID = "data-tobago-date-input-id";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String DATEINPUTID = DATE_INPUT_ID;
 
   /**
    * Marker for the OK-button of the date picker popup.
    */
-  public static final String DATEPICKEROK = "data-tobago-datepickerok";
+  public static final String DATE_PICKER_OK = "data-tobago-date-picker-ok";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String DATEPICKEROK = DATE_PICKER_OK;
 
   /**
    * Holds the day of a calendar control.
@@ -81,7 +93,11 @@ public final class DataAttributes {
   /**
    * Holds the first day of a week of a calendar control.
    */
-  public static final String FIRSTDAYOFWEEK = "data-tobago-firstdayofweek";
+  public static final String FIRST_DAY_OF_WEEK = "data-tobago-first-day-of-week";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String FIRSTDAYOFWEEK = FIRST_DAY_OF_WEEK;
 
   /**
    * Defines a maximum value.
@@ -96,7 +112,11 @@ public final class DataAttributes {
   /**
    * Holds the names of the months of a calendar control.
    */
-  public static final String MONTHNAMES = "data-tobago-monthnames";
+  public static final String MONTH_NAMES = "data-tobago-month-names";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String MONTHNAMES = MONTH_NAMES;
 
   public static final String PARTIALLY = "data-tobago-partially";
 
@@ -110,9 +130,17 @@ public final class DataAttributes {
    */
   public static final String RELOAD = "data-tobago-reload";
 
-  public static final String ROWACTION = "data-tobago-rowaction";
+  public static final String ROW_ACTION = "data-tobago-row-action";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String ROWACTION = ROW_ACTION;
+
+  public static final String SELECTION_MODE = "data-tobago-selection-mode";
 
-  public static final String SELECTIONMODE = "data-tobago-selectionmode";
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String SELECTIONMODE = SELECTION_MODE;
 
   /**
    * The selectable attribute e. g. for trees.
@@ -122,27 +150,47 @@ public final class DataAttributes {
   /**
    * Reference to a sheet.
    */
-  public static final String SHEETID = "data-tobago-sheetid";
+  public static final String SHEET_ID = "data-tobago-sheet-id";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String SHEETID = SHEET_ID;
 
   /**
    * Alternate to the src attribute, to implement a hover effect.
    */
-  public static final String SRCHOVER = "data-tobago-srchover";
+  public static final String SRC_HOVER = "data-tobago-src-hover";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String SRCHOVER = SRC_HOVER;
 
   /**
    * Alternate to the src attribute, to implement a hover effect.
    */
-  public static final String SRCDEFAULT = "data-tobago-srcdefault";
+  public static final String SRC_DEFAULT = "data-tobago-src-default";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String SRCDEFAULT = SRC_DEFAULT;
 
   /**
    * Alternate to the src attribute, icon open and close.
    */
-  public static final String SRCCLOSE = "data-tobago-srcclose";
+  public static final String SRC_CLOSE = "data-tobago-src-close";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String SRCCLOSE = SRC_CLOSE;
 
   /**
    * Alternate to the src attribute, icon open and close.
    */
-  public static final String SRCOPEN = "data-tobago-srcopen";
+  public static final String SRC_OPEN = "data-tobago-src-open";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String SRCOPEN = SRC_OPEN;
 
   /**
    * A way to transport style data in JSON format to the browser. With CSP the normal style attribute isn't allowed.
@@ -163,7 +211,11 @@ public final class DataAttributes {
   /**
    * Id of the parent node in a tree node.
    */
-  public static final String TREEPARENT = "data-tobago-treeparent";
+  public static final String TREE_PARENT = "data-tobago-tree-parent";
+
+  /** @deprecated Since 1.5.11 */
+  @Deprecated
+  public static final String TREEPARENT = TREE_PARENT;
 
   /**
    * Defines the unit, e. g. to differ between hours, minutes and seconds in a time control.

Modified: myfaces/tobago/trunk/tobago-core/src/test/java/org/apache/myfaces/tobago/renderkit/html/DataAttributesUnitTest.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-core/src/test/java/org/apache/myfaces/tobago/renderkit/html/DataAttributesUnitTest.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-core/src/test/java/org/apache/myfaces/tobago/renderkit/html/DataAttributesUnitTest.java (original)
+++ myfaces/tobago/trunk/tobago-core/src/test/java/org/apache/myfaces/tobago/renderkit/html/DataAttributesUnitTest.java Tue Jun 11 09:10:31 2013
@@ -30,6 +30,10 @@ public class DataAttributesUnitTest {
   public void testAttributeNames() throws IllegalAccessException {
     for (Field field : DataAttributes.class.getFields()) {
 
+      if (field.getAnnotation(Deprecated.class) != null) {
+        // ignore the check for deprecated fields
+        continue;
+      }
       String value = (String) field.get(null);
       Assert.assertTrue("Regexp check: value='" + value + "'", value.matches("data-tobago(-[a-z]+)*-[a-z]+"));
 

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/CalendarRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/CalendarRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/CalendarRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/CalendarRenderer.java Tue Jun 11 09:10:31 2013
@@ -77,14 +77,14 @@ public class CalendarRenderer extends La
     writer.writeStyleAttribute(style);
     String dateInputId = (String) output.getAttributes().get(Attributes.DATE_INPUT_ID);
     if (dateInputId != null) {
-      writer.writeAttribute(DataAttributes.DATEINPUTID, dateInputId, false);
+      writer.writeAttribute(DataAttributes.DATE_INPUT_ID, dateInputId, false);
     }
     writer.writeAttribute(DataAttributes.DAY, Integer.toString(calendar.get(Calendar.YEAR)), false);
     writer.writeAttribute(DataAttributes.MONTH, Integer.toString(1 + calendar.get(Calendar.MONTH)), false);
     writer.writeAttribute(DataAttributes.YEAR, Integer.toString(calendar.get(Calendar.DAY_OF_MONTH)), false);
 
-    writer.writeAttribute(DataAttributes.FIRSTDAYOFWEEK, Integer.toString(calendar.getFirstDayOfWeek()), false);
-    writer.writeAttribute(DataAttributes.MONTHNAMES, getMonthNames(locale), false);
+    writer.writeAttribute(DataAttributes.FIRST_DAY_OF_WEEK, Integer.toString(calendar.getFirstDayOfWeek()), false);
+    writer.writeAttribute(DataAttributes.MONTH_NAMES, getMonthNames(locale), false);
 
     // begin header
     writer.startElement(HtmlElements.DIV, null);

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/DatePickerRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/DatePickerRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/DatePickerRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/DatePickerRenderer.java Tue Jun 11 09:10:31 2013
@@ -146,7 +146,7 @@ public class DatePickerRenderer extends 
     buttonPanel.getChildren().add(okButton);
     okButton.setValueExpression(Attributes.LABEL, expressionFactory.createValueExpression(
         elContext, "#{tobagoContext.resourceBundle.datePickerOk}", String.class));
-    ComponentUtils.putDataAttributeWithPrefix(okButton, DataAttributes.DATEPICKEROK, true);
+    ComponentUtils.putDataAttributeWithPrefix(okButton, DataAttributes.DATE_PICKER_OK, true);
     okButton.getAttributes().put(Attributes.POPUP_CLOSE, "afterSubmit");
     okButton.setOmit(true);
     final UIButton cancelButton = (UIButton) CreateComponentUtils.createComponent(

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuCommandRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuCommandRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuCommandRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuCommandRenderer.java Tue Jun 11 09:10:31 2013
@@ -168,8 +168,8 @@ public class MenuCommandRenderer extends
         String imageHover
             = ResourceManagerUtils.getImageWithPath(facesContext, HtmlRendererUtils.createSrc(image, "Hover"), true);
         if (imageHover != null) {
-          writer.writeAttribute(DataAttributes.SRCDEFAULT, imageWithPath, false);
-          writer.writeAttribute(DataAttributes.SRCHOVER, imageHover, false);
+          writer.writeAttribute(DataAttributes.SRC_DEFAULT, imageWithPath, false);
+          writer.writeAttribute(DataAttributes.SRC_HOVER, imageHover, false);
         }
 
         writer.writeAttribute(HtmlAttributes.ALT, label.getText(), true);

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/SheetRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/SheetRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/SheetRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/SheetRenderer.java Tue Jun 11 09:10:31 2013
@@ -149,7 +149,7 @@ public class SheetRenderer extends Layou
 
     writer.writeAttribute(DataAttributes.PARTIALLY,
         HtmlRendererUtils.getRenderedPartiallyJavascriptArray(facesContext, sheet, sheet), false);
-    writer.writeAttribute(DataAttributes.SELECTIONMODE, sheet.getSelectable(), false);
+    writer.writeAttribute(DataAttributes.SELECTION_MODE, sheet.getSelectable(), false);
     writer.writeAttribute(DataAttributes.FIRST, Integer.toString(sheet.getFirst()), false);
 
     boolean rowAction = HtmlRendererUtils.renderSheetCommands(sheet, facesContext, writer);
@@ -336,7 +336,7 @@ public class SheetRenderer extends Layou
       }
       final String parentId = sheet.getRowParentClientId();
       if (parentId != null) {
-        writer.writeAttribute(DataAttributes.TREEPARENT, parentId, false);
+        writer.writeAttribute(DataAttributes.TREE_PARENT, parentId, false);
       }
 
       int columnIndex = -1;
@@ -870,7 +870,7 @@ public class SheetRenderer extends Layou
   private void encodeResizing(TobagoResponseWriter writer, AbstractUISheet sheet, int columnIndex) throws IOException {
     writer.startElement(HtmlElements.SPAN, null);
     writer.writeClassAttribute(Classes.create(sheet, "headerResize"));
-    writer.writeAttribute(DataAttributes.COLUMNINDEX, Integer.toString(columnIndex), false);
+    writer.writeAttribute(DataAttributes.COLUMN_INDEX, Integer.toString(columnIndex), false);
     writer.write("  "); // is needed for IE
     writer.endElement(HtmlElements.SPAN);
   }
@@ -921,7 +921,7 @@ public class SheetRenderer extends Layou
     menuItem.setLabel(ResourceManagerUtils.getPropertyNotNull(facesContext, "tobago", label));
     menuItem.setMarkup(markup);
     menuItem.setOnclick("/**/"); // XXX avoid submit
-    ComponentUtils.putDataAttributeWithPrefix(menuItem, DataAttributes.SHEETID, sheetId);
+    ComponentUtils.putDataAttributeWithPrefix(menuItem, DataAttributes.SHEET_ID, sheetId);
     menu.getChildren().add(menuItem);
   }
 

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TimeRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TimeRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TimeRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TimeRenderer.java Tue Jun 11 09:10:31 2013
@@ -100,7 +100,7 @@ public class TimeRenderer extends InputR
     writer.writeStyleAttribute(style);
     String dateInputId = (String) time.getAttributes().get(Attributes.DATE_INPUT_ID);
     if (dateInputId != null) {
-      writer.writeAttribute(DataAttributes.DATEINPUTID, dateInputId, false);
+      writer.writeAttribute(DataAttributes.DATE_INPUT_ID, dateInputId, false);
     }
     writer.writeAttribute(DataAttributes.PATTERN, pattern, false);
 

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java Tue Jun 11 09:10:31 2013
@@ -407,8 +407,8 @@ public abstract class ToolBarRendererBas
       String imageHover
           = ResourceManagerUtils.getImageWithPath(facesContext, HtmlRendererUtils.createSrc(iconName, "Hover"), true);
       if (imageHover != null) {
-        writer.writeAttribute(DataAttributes.SRCDEFAULT, image, false);
-        writer.writeAttribute(DataAttributes.SRCHOVER, imageHover, false);
+        writer.writeAttribute(DataAttributes.SRC_DEFAULT, image, false);
+        writer.writeAttribute(DataAttributes.SRC_HOVER, imageHover, false);
       }
       writer.writeAttribute(HtmlAttributes.ALT, label.getText(), true);
       writer.writeStyleAttribute(iconStyle);

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIconRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIconRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIconRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIconRenderer.java Tue Jun 11 09:10:31 2013
@@ -97,8 +97,8 @@ public class TreeIconRenderer extends La
     HtmlRendererUtils.writeDataAttributes(facesContext, writer, image);
     writer.writeAttribute(HtmlAttributes.SRC, source, true);
     if (folder) {
-      writer.writeAttribute(DataAttributes.SRCOPEN, openSource, true);
-      writer.writeAttribute(DataAttributes.SRCCLOSE, closedSource, true);
+      writer.writeAttribute(DataAttributes.SRC_OPEN, openSource, true);
+      writer.writeAttribute(DataAttributes.SRC_CLOSE, closedSource, true);
     }
     writer.writeAttribute(HtmlAttributes.ALT, "", false);
     writer.endElement(HtmlElements.IMG);

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIndentRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIndentRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIndentRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeIndentRenderer.java Tue Jun 11 09:10:31 2013
@@ -154,8 +154,8 @@ public class TreeIndentRenderer extends 
     final String src = expanded ? srcOpen : srcClose;
     writer.writeAttribute(HtmlAttributes.SRC, src, true);
     if (folder) {
-      writer.writeAttribute(DataAttributes.SRCOPEN, srcOpen, true);
-      writer.writeAttribute(DataAttributes.SRCCLOSE, srcClose, true);
+      writer.writeAttribute(DataAttributes.SRC_OPEN, srcOpen, true);
+      writer.writeAttribute(DataAttributes.SRC_CLOSE, srcClose, true);
     }
     writer.writeAttribute(HtmlAttributes.ALT, "", false);
     writer.endElement(HtmlElements.IMG);

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeListboxRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeListboxRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeListboxRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeListboxRenderer.java Tue Jun 11 09:10:31 2013
@@ -105,7 +105,7 @@ public class TreeListboxRenderer extends
       writer.writeNameAttribute(clientId + AbstractUITree.SELECT_STATE);
       writer.writeIdAttribute(clientId + AbstractUITree.SELECT_STATE);
       writer.writeAttribute(HtmlAttributes.VALUE, ";", false);
-      writer.writeAttribute(DataAttributes.SELECTIONMODE, tree.getSelectableAsEnum().name(), false);
+      writer.writeAttribute(DataAttributes.SELECTION_MODE, tree.getSelectableAsEnum().name(), false);
       writer.endElement(HtmlElements.INPUT);
     }
 
@@ -167,7 +167,7 @@ public class TreeListboxRenderer extends
     writer.startElement(HtmlElements.SELECT, tree);
     writer.writeClassAttribute(Classes.create(tree, "select"));
     if (parentId != null) {
-      writer.writeAttribute(DataAttributes.TREEPARENT, parentId, false);
+      writer.writeAttribute(DataAttributes.TREE_PARENT, parentId, false);
     }
 
     writer.writeAttribute(HtmlAttributes.SIZE, 9); // must be > 1, but the real size comes from the layout

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeMenuNodeRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeMenuNodeRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeMenuNodeRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeMenuNodeRenderer.java Tue Jun 11 09:10:31 2013
@@ -61,7 +61,7 @@ public class TreeMenuNodeRenderer extend
     writer.writeClassAttribute(Classes.create(node));
     HtmlRendererUtils.writeDataAttributes(facesContext, writer, node);
     if (parentId != null) {
-      writer.writeAttribute(DataAttributes.TREEPARENT, parentId, false);
+      writer.writeAttribute(DataAttributes.TREE_PARENT, parentId, false);
     }
 
     // In the case of a sheet, we need not hiding the node, because the whole TR will be hidden.
@@ -107,8 +107,8 @@ public class TreeMenuNodeRenderer extend
     writer.startElement(HtmlElements.IMG, null);
     writer.writeClassAttribute(Classes.create(node, "toggle"));
     writer.writeAttribute(HtmlAttributes.SRC, src, false);
-    writer.writeAttribute(DataAttributes.SRCOPEN, srcOpen, false);
-    writer.writeAttribute(DataAttributes.SRCCLOSE, srcClose, false);
+    writer.writeAttribute(DataAttributes.SRC_OPEN, srcOpen, false);
+    writer.writeAttribute(DataAttributes.SRC_CLOSE, srcClose, false);
     writer.writeAttribute(HtmlAttributes.ALT, "", false);
     writer.endElement(HtmlElements.IMG);
   }

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java Tue Jun 11 09:10:31 2013
@@ -73,7 +73,7 @@ public class TreeNodeRenderer extends Tr
     writer.writeClassAttribute(Classes.create(node));
     HtmlRendererUtils.writeDataAttributes(facesContext, writer, node);
     if (parentId != null) {
-      writer.writeAttribute(DataAttributes.TREEPARENT, parentId, false);
+      writer.writeAttribute(DataAttributes.TREE_PARENT, parentId, false);
     }
 
     Style style = new Style();

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/HtmlRendererUtils.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/HtmlRendererUtils.java?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/HtmlRendererUtils.java (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/HtmlRendererUtils.java Tue Jun 11 09:10:31 2013
@@ -681,7 +681,7 @@ public final class HtmlRendererUtils {
       }
     }
     if (commandMap != null) {
-      writer.writeAttribute(DataAttributes.ROWACTION, JsonUtils.encode(commandMap), true);
+      writer.writeAttribute(DataAttributes.ROW_ACTION, JsonUtils.encode(commandMap), true);
       return true;
     }
     return false;

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-calendar.js
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-calendar.js?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-sheet.js (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-sheet.js Tue Jun 11 09:10:31 2013
@@ -63,7 +63,7 @@ Tobago.Sheet.init = function(elements) {
   sheets.each(function initSheets() {
     var sheet = jQuery(this);
     var id = sheet.attr("id");
-    var commands = sheet.data("tobago-rowaction");
+    var commands = sheet.data("tobago-row-action");
     var click = commands ? commands.click : undefined;
     var dblclick = commands ? commands.dblclick : undefined;
     new Tobago.Sheet(id, undefined, undefined, undefined, undefined,
@@ -80,17 +80,17 @@ Tobago.Sheet.init = function(elements) {
   var commands;
   commands = Tobago.Utils.selectWidthJQuery(elements, ".tobago-menu-markup-sheetSelectAll");
   commands.click(function() {
-    var sheet = jQuery(Tobago.Utils.escapeClientId(jQuery(this).data("tobago-sheetid")));
+    var sheet = jQuery(Tobago.Utils.escapeClientId(jQuery(this).data("tobago-sheet-id")));
     Tobago.Sheet.selectAll(sheet);
   });
   commands = Tobago.Utils.selectWidthJQuery(elements, ".tobago-menu-markup-sheetDeselectAll");
   commands.click(function() {
-    var sheet = jQuery(Tobago.Utils.escapeClientId(jQuery(this).data("tobago-sheetid")));
+    var sheet = jQuery(Tobago.Utils.escapeClientId(jQuery(this).data("tobago-sheet-id")));
     Tobago.Sheet.deselectAll(sheet);
   });
   commands = Tobago.Utils.selectWidthJQuery(elements, ".tobago-menu-markup-sheetToggleAll");
   commands.click(function() {
-    var sheet = jQuery(Tobago.Utils.escapeClientId(jQuery(this).data("tobago-sheetid")));
+    var sheet = jQuery(Tobago.Utils.escapeClientId(jQuery(this).data("tobago-sheet-id")));
     Tobago.Sheet.toggleAll(sheet);
   });
 
@@ -297,7 +297,7 @@ Tobago.Sheet.setup2 = function (sheets) 
       // begin resizing
 //      console.log("begin");
 //      console.log(event);
-      var columnIndex = jQuery(this).data("tobago-columnindex");
+      var columnIndex = jQuery(this).data("tobago-column-index");
       var body = jQuery("body");
       var column = jQuery(this).closest("table").children("colgroup").children("col").eq(columnIndex);
       var filler = column.siblings("col:last");
@@ -401,7 +401,7 @@ Tobago.Sheet.setup2 = function (sheets) 
   // add selection listeners
   jQuery(sheets).each(function () {
     var sheet = jQuery(this);
-    var selectionMode = sheet.data("tobago-selectionmode");
+    var selectionMode = sheet.data("tobago-selection-mode");
     if (selectionMode == "single" || selectionMode == "singleOrNone" || selectionMode == "multi") {
       Tobago.Sheet.getRows(sheet).each(function () {
         var row = jQuery(this);
@@ -513,7 +513,7 @@ Tobago.Sheet.prototype.doSelection = fun
       var selector = Tobago.Sheet.getSelectorCheckbox(row);
       var rowIndex = row.index() + sheet.data("tobago-first");
       var wasSelected = Tobago.Sheet.isSelected(sheet, rowIndex);
-      var selectionMode = sheet.data("tobago-selectionmode");
+      var selectionMode = sheet.data("tobago-selection-mode");
 
       if ((!event.ctrlKey && !event.metaKey && selector.size() == 0)
           || selectionMode == "single" || selectionMode == "singleOrNone") {

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-tree.js
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-tree.js?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-tree.js (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-tree.js Tue Jun 11 09:10:31 2013
@@ -27,9 +27,9 @@ Tobago.Tree.toggleNode = function(elemen
   if (Tobago.Tree.isExpanded(node, expanded)) {
     Tobago.Tree.hideChildren(node);
     toggle.each(function() {
-      src = jQuery(this).data("tobago-srcclose");
+      src = jQuery(this).data("tobago-src-close");
       if (src == null) { // use the open icon if there is no close icon
-        src = jQuery(this).data("tobago-srcopen");
+        src = jQuery(this).data("tobago-src-open");
       }
       jQuery(this).attr("src", src);
       Tobago.fixPngAlpha(this);
@@ -44,9 +44,9 @@ Tobago.Tree.toggleNode = function(elemen
       Tobago.reloadComponent(element, data.attr("id"), toggle.parent().attr("id"), {});
     } else {
       toggle.each(function() {
-        src = jQuery(this).data("tobago-srcopen");
+        src = jQuery(this).data("tobago-src-open");
         if (src == null) { // use the close icon if there is no open icon
-          src = jQuery(this).data("tobago-srcclose");
+          src = jQuery(this).data("tobago-src-close");
         }
         jQuery(this).attr("src", src);
         Tobago.fixPngAlpha(this);
@@ -215,7 +215,7 @@ Tobago.Tree.rowIndex = function (node) {
 };
 
 Tobago.Tree.findChildren = function (node) {
-  var treeParentSelector = "[data-tobago-treeparent='" + node.attr("id") + "']";
+  var treeParentSelector = "[data-tobago-tree-parent='" + node.attr("id") + "']";
   var children;
   if (Tobago.Tree.isInSheet(node)) {
     children = node.parent("td").parent("tr").nextAll().children().children(treeParentSelector);
@@ -251,7 +251,7 @@ Tobago.TreeListbox.init = function(eleme
 Tobago.TreeListbox.initNextLevel = function() {
   var option = jQuery(this);
   var select = option.closest(".tobago-treeListbox-level").next()
-      .find("[data-tobago-treeparent='" + option.attr("id") + "']");
+      .find("[data-tobago-tree-parent='" + option.attr("id") + "']");
   if (select.length == 1) {
     option.data("tobago-select", select);
   } else {
@@ -289,7 +289,7 @@ Tobago.TreeListbox.onChange = function()
 };
 
 Tobago.TreeListbox.setSelected = function(listbox) {
-  var hidden = listbox.closest(".tobago-treeListbox").children("[data-tobago-selectionmode]");
+  var hidden = listbox.closest(".tobago-treeListbox").children("[data-tobago-selection-mode]");
   if (hidden.length == 1){
     var selectedValue = ";";
     listbox.children("option:selected").each(function() {
@@ -300,4 +300,4 @@ Tobago.TreeListbox.setSelected = functio
 };
 
 Tobago.registerListener(Tobago.TreeListbox.init, Tobago.Phase.DOCUMENT_READY);
-Tobago.registerListener(Tobago.TreeListbox.init, Tobago.Phase.AFTER_UPDATE);
\ No newline at end of file
+Tobago.registerListener(Tobago.TreeListbox.init, Tobago.Phase.AFTER_UPDATE);

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago.js
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago.js?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago.js (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago.js Tue Jun 11 09:10:31 2013
@@ -2393,7 +2393,7 @@ Tobago.ToolBar.init = function(elements)
           .addClass('tobago-toolBar-button-markup-hover').children('img')
           .each(function() {
         // set the src to the hover src url.
-        var hover = jQuery(this).data('tobago-srchover');
+        var hover = jQuery(this).data('tobago-src-hover');
         if (hover) {
           jQuery(this).attr('src', hover);
         }
@@ -2405,7 +2405,7 @@ Tobago.ToolBar.init = function(elements)
           .children('img')
           .each(function() {
         // restore the original/normal src url.
-        var normal = jQuery(this).data('tobago-srcdefault');
+        var normal = jQuery(this).data('tobago-src-default');
         if (normal) {
           jQuery(this).attr('src', normal);
         }
@@ -2423,7 +2423,7 @@ Tobago.ToolBar.init = function(elements)
           .addClass('tobago-boxToolBar-button-markup-hover').children('img')
           .each(function() {
         // set the src to the hover src url.
-        var hover = jQuery(this).data('tobago-srchover');
+        var hover = jQuery(this).data('tobago-src-hover');
         if (hover) {
           jQuery(this).attr('src', hover);
         }
@@ -2435,7 +2435,7 @@ Tobago.ToolBar.init = function(elements)
           .children('img')
           .each(function() {
         // restore the original/normal src url.
-        var normal = jQuery(this).data('tobago-srcdefault');
+        var normal = jQuery(this).data('tobago-src-default');
         if (normal) {
           jQuery(this).attr('src', normal);
         }
@@ -2466,7 +2466,7 @@ Tobago.ToolBar.init = function(elements)
           .addClass('tobago-tabGroupToolBar-button-markup-hover').children('img')
           .each(function() {
         // set the src to the hover src url.
-        var hover = jQuery(this).data('tobago-srchover');
+        var hover = jQuery(this).data('tobago-src-hover');
         if (hover) {
           jQuery(this).attr('src', hover);
         }
@@ -2478,7 +2478,7 @@ Tobago.ToolBar.init = function(elements)
           .children('img')
           .each(function() {
         // restore the original/normal src url.
-        var normal = jQuery(this).data('tobago-srcdefault');
+        var normal = jQuery(this).data('tobago-src-default');
         if (normal) {
           jQuery(this).attr('src', normal);
         }
--- myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-calendar.js (original)
+++ myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-calendar.js Tue Jun 11 09:10:31 2013
@@ -58,14 +58,14 @@ Tobago.Calendar.init = function (element
   });
 
   // init from data field, if there is any (e. g. we are in date picker popup)
-  var calendarWithDateField = Tobago.Utils.selectWidthJQuery(elements, ".tobago-calendar[data-tobago-dateinputid]");
+  var calendarWithDateField = Tobago.Utils.selectWidthJQuery(elements, ".tobago-calendar[data-tobago-date-input-id]");
   calendarWithDateField.each(function () {
     var calendar = jQuery(this);
     Tobago.Calendar.initFromDateField(calendar);
   });
 
   var okButton
-      = Tobago.Utils.selectWidthJQuery(elements, ".tobago-calendar").parent().find("button[data-tobago-datepickerok]");
+      = Tobago.Utils.selectWidthJQuery(elements, ".tobago-calendar").parent().find("button[data-tobago-date-picker-ok]");
   okButton.click(function () {
     var button = jQuery(this);
     var calendar = button.parent().parent().find(".tobago-calendar");
@@ -113,7 +113,7 @@ Tobago.Calendar.firstDayOffset = functio
 };
 
 Tobago.Calendar.getMonthName = function (calendar, month) {
-  return calendar.data("tobago-monthnames").split(',')[month - 1];
+  return calendar.data("tobago-month-names").split(',')[month - 1];
 };
 
 /**
@@ -193,7 +193,7 @@ Tobago.Calendar.selectDay = function (ca
 //  alert(id + " "  + row + " " + column);
   var month = calendar.data("tobago-month");
   var year = calendar.data("tobago-year");
-  var firstDayOfWeek = calendar.data("tobago-firstdayofweek");
+  var firstDayOfWeek = calendar.data("tobago-first-day-of-week");
   var firstDayOffset = Tobago.Calendar.firstDayOffset(month, year, firstDayOfWeek);
   Tobago.Calendar.initCalendarData(calendar, year, month, row * 7 + column - firstDayOffset + 1);
   Tobago.Calendar.initCalendar(calendar);
@@ -203,7 +203,7 @@ Tobago.Calendar.initCalendar = function 
   var day = calendar.data("tobago-day");
   var month = calendar.data("tobago-month");
   var year = calendar.data("tobago-year");
-  var firstDayOfWeek = calendar.data("tobago-firstdayofweek");
+  var firstDayOfWeek = calendar.data("tobago-first-day-of-week");
   var firstDayOffset = Tobago.Calendar.firstDayOffset(month, year, firstDayOfWeek);
   var prevMonthLength = Tobago.Calendar.getPreviousMonthLength(month, year);
   var monthLength = Tobago.Calendar.getMonthLength(month, year);
@@ -240,11 +240,11 @@ Tobago.Calendar.initCalendar = function 
 };
 
 /**
  * @param element jQuery element with a reference to the date field (with data attribute tobago-dateinputid)
  * @return the date field as jQuery object
  */
 Tobago.Calendar.getDateField = function (element) {
-  return jQuery(Tobago.Utils.escapeClientId(element.data("tobago-dateinputid")));
+  return jQuery(Tobago.Utils.escapeClientId(element.data("tobago-date-input-id")));
 };
 
 Tobago.Calendar.initFromDateField = function (calendar) {
@@ -328,7 +328,7 @@ Tobago.Time.init = function (elements) {
       });
 
   // init from data field, if there is any (e. g. we are in date picker popup)
-  Tobago.Utils.selectWidthJQuery(elements, ".tobago-time[data-tobago-dateinputid]")
+  Tobago.Utils.selectWidthJQuery(elements, ".tobago-time[data-tobago-date-input-id]")
       .each(function () {
         Tobago.Time.initFromDateField(jQuery(this));
       });
@@ -240,11 +240,11 @@ Tobago.Calendar.initCalendar = function 
 
 /**
- * @param element jQuery element with a reference to the date field (with data attribute tobago-dateinputid)
+ * @param element jQuery element with a reference to the date field (with data attribute tobago-date-input-id)
  * @return the date field as jQuery object
  */

Modified: myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-sheet.js
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/tobago-theme/tobago-theme-standard/src/main/resources/org/apache/myfaces/tobago/renderkit/html/standard/standard/script/tobago-sheet.js?rev=1491710&r1=1491709&r2=1491710&view=diff
==============================================================================